.. _getting_started:

###############
Getting Started
###############


Welcome to the "Getting Started" section of the documentation.
Here you can find an overview over the basics of ODL, a step-by-step installation guide and some in-depth code examples that show the capabilities of the framework.


.. toctree::
   :maxdepth: 1

   about_odl
   installing
   installing_conda
   installing_pip
   installing_source
   installing_extensions
   first_steps
